/*
 Copyright 2021 Adobe. All rights reserved.
 This file is licensed to you under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License. You may obtain a copy
 of the License at http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software distributed under
 the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR REPRESENTATIONS
 OF ANY KIND, either express or implied. See the License for the specific language
 governing permissions and limitations under the License.
 */

import Foundation

/// UI Message delegate which is used to listen for current message lifecycle events
@objc(AEPMessagingDelegate) public protocol MessagingDelegate {

    /// Invoked when the any message is displayed
    /// - Parameters:
    ///     - message: UIMessaging message that is being displayed
    func onShow(message: Showable)

    /// Invoked when the any message is dismissed
    /// - Parameters:
    ///     - message: UIMessaging message that is being dismissed
    func onDismiss(message: Showable)

    /// Used to find whether messages should be shown or not
    /// - Parameters:
    ///     - message: UIMessaging message that is about to get displayed
    /// - Returns: true if the message should be shown else false
    func shouldShowMessage(message: Showable) -> Bool
}
